# Antelope
Antelope is a database for electrophysiology data. It provides a web based GUI, automatic spikesorting, and data analysis tools built in.

Please read our [documentation](https://antelope.readthedocs.io/en/latest/).
